==> foundry_platform_sdk-0.28.0.tar.gz: foundry_platform_sdk-0.28.0/foundry/v2/ontologies/models/_object_set_interface_base_type.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Literal
from typing import cast

import pydantic

from foundry.v2.ontologies.models._object_set_interface_base_type_dict import (
    ObjectSetInterfaceBaseTypeDict,
)  # NOQA


class ObjectSetInterfaceBaseType(pydantic.BaseModel):
    """ObjectSetInterfaceBaseType"""

    interface_type: pydantic.StrictStr = pydantic.Field(alias="interfaceType")
    """
    An object set with objects that implement the interface with the given interface API name. The objects in 
    the object set will only have properties that implement properties of the given interface. This is currently 
    unsupported and an exception will be thrown if used.
    """

    type: Literal["interfaceBase"]

    model_config = {"extra": "allow"}

    def to_dict(self) -> ObjectSetInterfaceBaseTypeDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            ObjectSetInterfaceBaseTypeDict, self.model_dump(by_alias=True, exclude_unset=True)
        )

==> foundry_platform_sdk-0.73.0.tar.gz: foundry_platform_sdk-0.73.0/foundry/v2/ontologies/models/_object_set_interface_base_type.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Literal
from typing import cast

import pydantic

from foundry.v2.ontologies.models._object_set_interface_base_type_dict import (
    ObjectSetInterfaceBaseTypeDict,
)  # NOQA


class ObjectSetInterfaceBaseType(pydantic.BaseModel):
    """ObjectSetInterfaceBaseType"""

    interface_type: str = pydantic.Field(alias="interfaceType")

    """
    An object set with objects that implement the interface with the given interface API name. The objects in 
    the object set will only have properties that implement properties of the given interface. This is currently 
    unsupported and an exception will be thrown if used.
    """

    type: Literal["interfaceBase"] = "interfaceBase"

    model_config = {"extra": "allow"}

    def to_dict(self) -> ObjectSetInterfaceBaseTypeDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(
            ObjectSetInterfaceBaseTypeDict, self.model_dump(by_alias=True, exclude_unset=True)
        )
